==> foundation-2.6.1.tgz: package/Torsos/Torsos.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Torsos = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M40.348 49.813a13.061 13.061 0 002.527-2.121c-2.683-4.036-4.239-8.966-4.239-14.191 0-3.492.689-6.798 1.896-9.787-1.879-1.25-4.026-2.022-6.349-2.022-7.114 0-12.872 6.702-12.872 14.978 0 5.79 2.83 10.801 6.962 13.295l-17.448 8.121c-1.087.511-1.804 1.739-1.804 3.111v13.771c0 1.846 1.289 3.341 2.874 3.341h11.532v-14.45c0-3.739 2.068-7.121 5.275-8.623l11.646-5.423z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M88.772 60.017L73.749 52.85l-6.353-3.03c2.775-1.748 5.028-4.445 6.503-7.695a20.872 20.872 0 001.866-8.625c0-1.753-.278-3.416-.666-5.023-1.89-7.782-7.968-13.515-15.263-13.515-7.158 0-13.144 5.529-15.15 13.09-.463 1.734-.782 3.538-.782 5.448 0 3.319.775 6.412 2.092 9.103 1.523 3.121 3.78 5.696 6.527 7.35l-6.085 2.834L30.93 60.01c-1.348.631-2.233 2.151-2.233 3.849v17.043c0 2.284 1.591 4.136 3.557 4.136H87.42c1.965 0 3.557-1.852 3.557-4.136V63.859c0-1.691-.871-3.197-2.205-3.842z"
  }));
});
Torsos.displayName = 'Torsos';
export const TorsosDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Torsos/Torsos.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Torsos = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M40.348 49.813a13.061 13.061 0 002.527-2.121c-2.683-4.036-4.239-8.966-4.239-14.191 0-3.492.689-6.798 1.896-9.787-1.879-1.25-4.026-2.022-6.349-2.022-7.114 0-12.872 6.702-12.872 14.978 0 5.79 2.83 10.801 6.962 13.295l-17.448 8.121c-1.087.511-1.804 1.739-1.804 3.111v13.771c0 1.846 1.289 3.341 2.874 3.341h11.532v-14.45c0-3.739 2.068-7.121 5.275-8.623l11.646-5.423z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M88.772 60.017L73.749 52.85l-6.353-3.03c2.775-1.748 5.028-4.445 6.503-7.695a20.872 20.872 0 001.866-8.625c0-1.753-.278-3.416-.666-5.023-1.89-7.782-7.968-13.515-15.263-13.515-7.158 0-13.144 5.529-15.15 13.09-.463 1.734-.782 3.538-.782 5.448 0 3.319.775 6.412 2.092 9.103 1.523 3.121 3.78 5.696 6.527 7.35l-6.085 2.834L30.93 60.01c-1.348.631-2.233 2.151-2.233 3.849v17.043c0 2.284 1.591 4.136 3.557 4.136H87.42c1.965 0 3.557-1.852 3.557-4.136V63.859c0-1.691-.871-3.197-2.205-3.842z"
  }));
});
Torsos.displayName = 'Torsos';
export var TorsosDimensions = {
  height: 100,
  width: 100
};
